@@ -2,7 +2,7 @@ package Yars::Command::yars_disk_scan;
 
 # PODNAME: yars_disk_scan
 # ABSTRACT: scan a disk for corruption and report corrupt files to stdout
-our $VERSION = '0.97_01'; # VERSION
+our $VERSION = '0.87'; # VERSION
 
 
 use strict;
@@ -39,8 +39,7 @@ sub main {
         INFO "Checking disk $root";
         File::Find::Rule->new->file->exec(sub {
              my $md5 = $File::Find::dir;
-             my $root_re = quotemeta $root;
-             $md5 =~ s/^$root_re//;
+             $md5 =~ s/^$root//;
              $md5 =~ s[/][]g;
              if ($md5 =~ /^tmp/) {
                 DEBUG "Skipping tmp file in $File::Find::dir";
@@ -72,7 +71,7 @@ Yars::Command::yars_disk_scan - code for yars_disk_scan
 
 =head1 DESCRIPTION
 
-This module contains the machinery for the command line program L<yars_disk_scan>
+Tis module contains the machinery for the command line program L<yars_disk_scan>
 
 =head1 SEE ALSO
 
